@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cassava
 version: 0.4.5.0
-id: cassava-0.4.5.0-6082ca548288f636f02a18aadbab9757
-key: cassa_DDeaDLtt5NHGnZM7cA6rlX
+id: cassava-0.4.5.0-16a8710c3a0da375311b9db5f9f0d63e
+key: cassa_HBrMWiH3yz23sEBshQWh49
 license: BSD3
 copyright: (c) 2012 Johan Tibell
            (c) 2012 Bryan O'\''Sullivan
@@ -26,10 +26,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/cassava-0.4.5.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/cassava-0.4.5.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/cassava-0.4.5.0
-hs-libraries: HScassava-0.4.5.0-DDeaDLtt5NHGnZM7cA6rlX
+hs-libraries: HScassava-0.4.5.0-HBrMWiH3yz23sEBshQWh49
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
-    attoparsec-0.13.0.1-c82a92403ed30683a5cb6228370c626c
+    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
